==> dl.php?src=linea21_1_8.zip: linea21/sdi/sup.php <==
<?php
/**
 * Indicator / SDI module
 * 
 * Delete given publication from back-office
 * 
 * @package linea21\modules\sdi
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')){
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

$link_det=$rub_link."&amp;todo=det&amp;id=";
$link_det2=$rub_link."&amp;todo=det&amp;id=";
$link_sup=$rub_link."&amp;todo=sup&amp;id=";
$link_mod=$rub_link."&amp;todo=mod&amp;id=";

if(!isset($_GET['id']) && !isset($_POST['id'])) {
  $id="1";
} else {
  if(isset($_POST['id']))	$id=$_POST['id'];
  if(isset($_GET['id']))	$id=$_GET['id'];
}

if(isset($_POST['valider'])) {
  $id=$_POST['id'];
  $sdi_object= new sdi;
  $link_confirm="confirm.php?rub=".$rub."&todo=".$todo;

  $result=$sdi_object->DeleteSdi($id, $sql_object);
  if($result) header("Location: ".$link_confirm);
  else  system_error();
}

$sdi_object= new sdi;
//$data_sdii=$sdi_object->GetInfoSdi($id, $sql_object);

$req_sdii=SQL_getInfoSdi($id);
$data_sdii = $sql_object -> DBSelect($req_sdii);

// Do record exists?
if(!isset($data_sdii[0]['sdii_name'])) redirect_to('@module_default');

$navtitle=_t('sdi','sup')." : ".$data_sdii[0]['sdii_name'];
$req_allsditheme=SQL_getAllsditheme($data_sdii[0]['sdii_theme']) ;
$result_Allsditheme=$sql_object->DBSelect($req_allsditheme);
$theme_test=$result_Allsditheme[0]['countsdi'];
?>
<div id="chemin">
  <ul>
  	<li><a href="index.php" class="chemin_home"><?php echo _t('way','home') ?></a></li>
  	<li><a href="<?php echo $rub_link; ?>" id="chemin_<?php echo $rub; ?>" class="chemin_rub"><?php echo _t('menu','sdi')?></a></li>
  	<li><span><?php echo formatnavTitle($navtitle) ; ?></span></li>
  </ul>
</div>
<!--end barre haute -->
<div class="contentcontainer">
<?php
include_once(override($dir.'/menurub.php', THEME_ADMIN_PATH));
?>
<div id="content"><?php
if(isset($integrity) && is_string($integrity)) display_errors($integrity);
?>
<h2><?php echo formatTitleh2(_t('sdi', 'sup') . ' : ' . $data_sdii[0]['sdii_name']); ?></h2>

<form id="supyp" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post">
  <div class="info">
    <?php echo '<p><i class="icon-trash"></i> '._t('sdi','sup_sdi_warning').'</p>'; ?>
    <?php echo '<p>'._t('sdi','sup_sdi_warning2').'</p>'; ?>
    <?php
    if ($theme_test==1) {
      echo '<p>'._t('sdi','sup_sdi_warning3').'</p>';
    } ?>
  </div>
  <div>
    <input name="id" type="hidden" value="<?php echo $id; ?>" />
    <input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
    <input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
    <?php echo cancel_button($link_det2.$id); ?>
    <input name="valider" type="submit" value="<?php echo _t('btn','valid') ?>" class="button" 	id="valider" />
  </div>
</form>
</div> <!-- closing #content -->
</div> <!-- closing .contentcontainer -->

==> dl.php?src=linea21_2_0_0.zip: linea21/sdi/sup.php <==
<?php
/**
 * Indicator / SDI module
 * 
 * Delete given publication from back-office
 * 
 * @package linea21\modules\sdi
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')){
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

$link_det=$rub_link."&amp;todo=det&amp;id=";
$link_det2=$rub_link."&amp;todo=det&amp;id=";
$link_sup=$rub_link."&amp;todo=sup&amp;id=";
$link_mod=$rub_link."&amp;todo=mod&amp;id=";

if(!isset($_GET['id']) && !isset($_POST['id'])) {
  $id="1";
} else {
  if(isset($_POST['id']))	$id=$_POST['id'];
  if(isset($_GET['id']))	$id=$_GET['id'];
}

if(isset($_POST['valider'])) {
  $id=$_POST['id'];
  $sdi_object= new sdi;
  $link_confirm="confirm.php?rub=".$rub."&todo=".$todo;

  $result=$sdi_object->DeleteSdi($id, $sql_object);
  if($result) header("Location: ".$link_confirm);
  else  system_error();
}

$sdi_object= new sdi;
//$data_sdii=$sdi_object->GetInfoSdi($id, $sql_object);

$req_sdii=SQL_getInfoSdi($id);
$data_sdii = $sql_object -> DBSelect($req_sdii);

// Do record exists?
if(!isset($data_sdii[0]['sdii_name'])) redirect_to('@module_default');

$navtitle=_t('sdi','sup')." : ".$data_sdii[0]['sdii_name'];

$res = $sql_object->DBSelect(SQL_getAllsdiByLevel($data_sdii[0]['sdii_level']) );
$level_test = $res[0]['countsdi'];
?>
<div id="chemin">
  <ul>
  	<li><a href="index.php" class="chemin_home"><?php echo _t('way','home') ?></a></li>
  	<li><a href="<?php echo $rub_link; ?>" id="chemin_<?php echo $rub; ?>" class="chemin_rub"><?php echo _t('menu','sdi')?></a></li>
  	<li><span><?php echo formatnavTitle($navtitle) ; ?></span></li>
  </ul>
</div>
<!--end barre haute -->
<div class="contentcontainer">
<?php
include_once(override($dir.'/menurub.php', THEME_ADMIN_PATH));
?>
<div id="content"><?php
if(isset($integrity) && is_string($integrity)) display_errors($integrity);
?>
<h2><?php echo formatTitleh2(_t('sdi', 'sup')); ?></h2>
<div class="subtitle" id="indicator-subtitle"><?php echo formatText($data_sdii[0]['sdii_name'], '2HTML'); ?></div>

<form id="supyp" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post">
  <div class="info">
    <?php echo '<p><i class="icon-trash"></i> '._t('sdi','sup_sdi_warning').'</p>'; ?>
    <?php echo '<p>'._t('sdi','sup_sdi_warning2').'</p>'; ?>
    <?php
    if ($level_test==1) {
      echo '<p>'._t('sdi','sup_sdi_warning3').'</p>';
    } ?>
  </div>
  <div>
    <input name="id" type="hidden" value="<?php echo $id; ?>" />
    <input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
    <input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
    <?php echo cancel_button($link_det2.$id); ?>
    <input name="valider" type="submit" value="<?php echo _t('btn','valid') ?>" class="button" 	id="valider" />
  </div>
</form>
</div> <!-- closing #content -->
</div> <!-- closing .contentcontainer -->
